@@ -8,3 +8,7 @@ class CapSettings(object):
             'adminplus',
             'django.contrib.admin.apps.SimpleAdminConfig'
         ] + super().INSTALLED_APPS
+
+    @property
+    def DATE_INPUT_FORMATS(self):
+        return ['%d/%m/%Y'] + super().DATE_INPUT_FORMATS
